@@ -57,6 +57,11 @@ circle_area
 right_rect_pyramid
     A function that calculates the volume of a right rectangle pyramid
 
+epe_calc
+    A function that calculates Elastic Potential Energy
+
+circumference
+    A function that calculates the circumference of a circle
 
 """
 
